# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ('image_collection', '0006_imageslide_data_class'),
    ]

    operations = [
        migrations.AddField(
            model_name='imageslide',
            name='is_visible_on_mobile',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='imageslide',
            name='mobile_link',
            field=models.CharField(help_text='i.e. "{route: "shop/cateogry", categoryName: "artworks"}"', max_length=4000, verbose_name='mobile link', blank=True),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ('image_collection', '0008_auto_20160306_2156'),
    ]

    operations = [
        migrations.AddField(
            model_name='imageslide',
            name='update_date',
            field=models.DateTimeField(null=True, verbose_name='update date', blank=True),
        ),
    ]



"""Templatetags for the image_collection app."""
from distutils.version import StrictVersion

from django import get_version, template

from ..models import ImageCollection


register = template.Library()


django_version = get_version()
if StrictVersion(django_version) < StrictVersion('1.9'):
    filename = 'file_name'
else:
    filename = 'filename'

tag_kwargs = {
    'takes_context': True,
    filename: 'image_collection/tags/bs3_carousel.html'
}


@register.inclusion_tag(**tag_kwargs)
def render_bs3_carousel(context, identifier):
    """Renders an image collection as Bootstrap 3 carousel."""
    try:
        collection = ImageCollection.objects.get(identifier=identifier)
    except ImageCollection.DoesNotExist:
        collection = None
    context.update({'collection': collection})
    return context



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ('image_collection', '0009_imageslide_update_date'),
    ]

    operations = [
        migrations.AlterField(
            model_name='imageslide',
            name='update_date',
            field=models.DateTimeField(auto_now=True, verbose_name='update date', null=True),
        ),
    ]
